@@ -21,34 +21,28 @@
 #include "apps/kmix.h"
 
 // include files for Qt
+#include <QApplication>
 #include <QCheckBox>
 #include <QLabel>
 #include <QDesktopWidget>
+#include <QMenuBar>
 #include <QPushButton>
 #include <qradiobutton.h>
 #include <QCursor>
 #include <QString>
+#include <QTabWidget>
+#include <QPointer>
 
 // include files for KDE
-#include <KConfigSkeleton>
-#include <kcombobox.h>
 #include <KGlobalAccel>
 #include <kiconloader.h>
 #include <kmessagebox.h>
-#include <kmenubar.h>
-#include <klocale.h>
+#include <klocalizedstring.h>
 #include <kconfig.h>
-#include <kaction.h>
-#include <ktoggleaction.h>
-#include <kapplication.h>
 #include <kstandardaction.h>
-#include <khelpmenu.h>
-#include <kdebug.h>
 #include <kxmlguifactory.h>
-#include <kglobal.h>
 #include <kactioncollection.h>
 #include <KProcess>
-#include <KTabWidget>
 
 // KMix
 #include "gui/guiprofile.h"
@@ -67,22 +61,10 @@
 #include "gui/dialogaddview.h"
 #include "gui/dialogselectmaster.h"
 #include "dbus/dbusmixsetwrapper.h"
-#ifdef X_KMIX_KF5_BUILD
-#include <QtDBus/QDBusInterface>
-#include <QtDBus/QDBusPendingCall>
-#else
-#include "gui/osdwidget.h"
-#endif
-
-#ifdef X_KMIX_KF5_BUILD
-#define CLASS_Action QAction
+#include "kmix_debug.h"
+#include <QDBusInterface>
+#include <QDBusPendingCall>
 #include <QKeySequence>
-#define CLASS_KShortcut QKeySequence
-#else
-#define CLASS_Action KAction
-#define CLASS_KShortcut KShortcut
-#define QStringLiteral QLatin1String
-#endif
 
 /* KMixWindow
  * Constructs a mixer window (KMix main window)
@@ -101,7 +83,8 @@ KMixWindow::KMixWindow(bool invisible, bool reset) :
 	initActions(); // init actions first, so we can use them in the loadConfig() already
 	loadAndInitConfig(reset); // Load config before initMixer(), e.g. due to "MultiDriver" keyword
 	initActionsLate(); // init actions that require a loaded config
-	KGlobal::locale()->insertCatalog(QLatin1String("kmix-controls"));
+	// TODO: Port to KF5
+	//KGlobal::locale()->insertCatalog(QLatin1String("kmix-controls"));
 	initWidgets();
 	initPrefDlg();
 	DBusMixSetWrapper::initialize(this, QStringLiteral("/Mixers"));
@@ -116,8 +99,8 @@ KMixWindow::KMixWindow(bool invisible, bool reset) :
 		recreateGUI(false, QString(), true, reset);
 	}
 
-	if (!kapp->isSessionRestored() ) // done by the session manager otherwise
-	setInitialSize();
+	if (!qApp->isSessionRestored() ) // done by the session manager otherwise
+		setInitialSize();
 
 	fixConfigAfterRead();
 	theKMixDeviceManager->initHotplug();
@@ -127,7 +110,7 @@ KMixWindow::KMixWindow(bool invisible, bool reset) :
 	if (m_startVisible && !invisible)
 		show(); // Started visible
 
-	connect(kapp, SIGNAL(aboutToQuit()), SLOT(saveConfig()) );
+	connect(qApp, SIGNAL(aboutToQuit()), SLOT(saveConfig()) );
 
 	ControlManager::instance().addListener(
 			QString(), // All mixers (as the Global master Mixer might change)
@@ -143,9 +126,7 @@ KMixWindow::~KMixWindow()
 	ControlManager::instance().removeListener(this);
 
 	delete m_dsm;
-#ifndef X_KMIX_KF5_BUILD
-	delete osdWidget;
-#endif
+
 	// -1- Cleanup Memory: clearMixerWidgets
 	while (m_wsMixers->count() != 0)
 	{
@@ -197,68 +178,67 @@ void KMixWindow::initActions()
 	//actionCollection()->addAction(QStringLiteral( a->objectName()), a );
 	KStandardAction::preferences(this, SLOT(showSettings()), actionCollection());
 	KStandardAction::keyBindings(guiFactory(), SLOT(configureShortcuts()), actionCollection());
-	CLASS_Action* action = actionCollection()->addAction(QStringLiteral("launch_kdesoundsetup"));
-	action->setText(i18n("Audio Setup"));
+	QAction* action = actionCollection()->addAction(QStringLiteral("launch_kdesoundsetup"));
+	action->setText(i18n("Audio Setup..."));
 	connect(action, SIGNAL(triggered(bool)), SLOT(slotKdeAudioSetupExec()));
 
 	action = actionCollection()->addAction(QStringLiteral("hwinfo"));
 	action->setText(i18n("Hardware &Information"));
 	connect(action, SIGNAL(triggered(bool)), SLOT(slotHWInfo()));
+
 	action = actionCollection()->addAction(QStringLiteral("hide_kmixwindow"));
 	action->setText(i18n("Hide Mixer Window"));
 	connect(action, SIGNAL(triggered(bool)), SLOT(hideOrClose()));
-	action->setShortcut(QKeySequence(Qt::Key_Escape));
+	actionCollection()->setDefaultShortcut(action, Qt::Key_Escape);
+
 	action = actionCollection()->addAction(QStringLiteral("toggle_channels_currentview"));
 	action->setText(i18n("Configure &Channels..."));
 	connect(action, SIGNAL(triggered(bool)), SLOT(slotConfigureCurrentView()));
+
 	action = actionCollection()->addAction(QStringLiteral("select_master"));
 	action->setText(i18n("Select Master Channel..."));
 	connect(action, SIGNAL(triggered(bool)), SLOT(slotSelectMaster()));
 
 	action = actionCollection()->addAction(QStringLiteral("save_1"));
-	action->setShortcut(CLASS_KShortcut(Qt::CTRL + Qt::SHIFT + Qt::Key_1));
+	actionCollection()->setDefaultShortcut(action, Qt::CTRL + Qt::SHIFT + Qt::Key_1);
 	action->setText(i18n("Save volume profile 1"));
 	connect(action, SIGNAL(triggered(bool)), SLOT(saveVolumes1()));
 
 	action = actionCollection()->addAction(QStringLiteral("save_2"));
-	action->setShortcut(CLASS_KShortcut(Qt::CTRL + Qt::SHIFT + Qt::Key_2));
+	actionCollection()->setDefaultShortcut(action, Qt::CTRL + Qt::SHIFT + Qt::Key_2);
 	action->setText(i18n("Save volume profile 2"));
 	connect(action, SIGNAL(triggered(bool)), SLOT(saveVolumes2()));
 
 	action = actionCollection()->addAction(QStringLiteral("save_3"));
-	action->setShortcut(CLASS_KShortcut(Qt::CTRL + Qt::SHIFT + Qt::Key_3));
+	actionCollection()->setDefaultShortcut(action, Qt::CTRL + Qt::SHIFT + Qt::Key_3);
 	action->setText(i18n("Save volume profile 3"));
 	connect(action, SIGNAL(triggered(bool)), SLOT(saveVolumes3()));
 
 	action = actionCollection()->addAction(QStringLiteral("save_4"));
-	action->setShortcut(CLASS_KShortcut(Qt::CTRL + Qt::SHIFT + Qt::Key_4));
+	actionCollection()->setDefaultShortcut(action, Qt::CTRL + Qt::SHIFT + Qt::Key_4);
 	action->setText(i18n("Save volume profile 4"));
 	connect(action, SIGNAL(triggered(bool)), SLOT(saveVolumes4()));
 
 	action = actionCollection()->addAction(QStringLiteral("load_1"));
-	action->setShortcut(CLASS_KShortcut(Qt::CTRL + Qt::Key_1));
+	actionCollection()->setDefaultShortcut(action, Qt::CTRL + Qt::Key_1);
 	action->setText(i18n("Load volume profile 1"));
 	connect(action, SIGNAL(triggered(bool)), SLOT(loadVolumes1()));
 
 	action = actionCollection()->addAction(QStringLiteral("load_2"));
-	action->setShortcut(CLASS_KShortcut(Qt::CTRL + Qt::Key_2));
+	actionCollection()->setDefaultShortcut(action, Qt::CTRL + Qt::Key_2);
 	action->setText(i18n("Load volume profile 2"));
 	connect(action, SIGNAL(triggered(bool)), SLOT(loadVolumes2()));
 
 	action = actionCollection()->addAction(QStringLiteral("load_3"));
-	action->setShortcut(CLASS_KShortcut(Qt::CTRL + Qt::Key_3));
+	actionCollection()->setDefaultShortcut(action, Qt::CTRL + Qt::Key_3);
 	action->setText(i18n("Load volume profile 3"));
 	connect(action, SIGNAL(triggered(bool)), SLOT(loadVolumes3()));
 
 	action = actionCollection()->addAction(QStringLiteral("load_4"));
-	action->setShortcut(CLASS_KShortcut(Qt::CTRL + Qt::Key_4));
+	actionCollection()->setDefaultShortcut(action, Qt::CTRL + Qt::Key_4);
 	action->setText(i18n("Load volume profile 4"));
 	connect(action, SIGNAL(triggered(bool)), SLOT(loadVolumes4()));
 
-#ifndef X_KMIX_KF5_BUILD
-	osdWidget = new OSDWidget();
-#endif
-
 	createGUI(QLatin1String("kmixui.rc"));
 }
 
@@ -266,33 +246,21 @@ void KMixWindow::initActionsLate()
 {
 	if (m_autouseMultimediaKeys)
 	{
-		CLASS_Action* globalAction = actionCollection()->addAction(QStringLiteral("increase_volume"));
+		QAction* globalAction = actionCollection()->addAction(QStringLiteral("increase_volume"));
 		globalAction->setText(i18n("Increase Volume"));
 
-#ifdef X_KMIX_KF5_BUILD
 		KGlobalAccel::setGlobalShortcut(globalAction, Qt::Key_VolumeUp);
-#else
-		globalAction->setGlobalShortcut(CLASS_KShortcut(Qt::Key_VolumeUp));
-#endif
 
 		connect(globalAction, SIGNAL(triggered(bool)), SLOT(slotIncreaseVolume()));
 
 		globalAction = actionCollection()->addAction(QStringLiteral("decrease_volume"));
 		globalAction->setText(i18n("Decrease Volume"));
-#ifdef X_KMIX_KF5_BUILD
 		KGlobalAccel::setGlobalShortcut(globalAction, Qt::Key_VolumeDown);
-#else
-		globalAction->setGlobalShortcut(CLASS_KShortcut(Qt::Key_VolumeDown));
-#endif
 		connect(globalAction, SIGNAL(triggered(bool)), SLOT(slotDecreaseVolume()));
 
 		globalAction = actionCollection()->addAction(QStringLiteral("mute"));
 		globalAction->setText(i18n("Mute"));
-#ifdef X_KMIX_KF5_BUILD
 		KGlobalAccel::setGlobalShortcut(globalAction, Qt::Key_VolumeMute);
-#else
-		globalAction->setGlobalShortcut(CLASS_KShortcut(Qt::Key_VolumeMute));
-#endif
 		connect(globalAction, SIGNAL(triggered(bool)), SLOT(slotMute()));
 	}
 }
@@ -307,6 +275,7 @@ void KMixWindow::initActionsAfterInitMixer()
 				IconSize(KIconLoader::Toolbar));
 		QPushButton* _cornerLabelNew = new QPushButton();
 		_cornerLabelNew->setIcon(cornerNewPM);
+		_cornerLabelNew->setToolTip(i18n("Add new view"));
 		//cornerLabelNew->setSizePolicy(QSizePolicy());
 		m_wsMixers->setCornerWidget(_cornerLabelNew, Qt::TopLeftCorner);
 		connect(_cornerLabelNew, SIGNAL(clicked()), SLOT(newView()));
@@ -321,7 +290,7 @@ void KMixWindow::initPrefDlg()
 
 void KMixWindow::initWidgets()
 {
-	m_wsMixers = new KTabWidget();
+	m_wsMixers = new QTabWidget();
 	m_wsMixers->setDocumentMode(true);
 	setCentralWidget(m_wsMixers);
 	m_wsMixers->setTabsClosable(false);
@@ -338,11 +307,7 @@ void KMixWindow::initWidgets()
 
 void KMixWindow::setInitialSize()
 {
-#ifdef X_KMIX_KF5_BUILD
 	KConfigGroup config(KSharedConfig::openConfig(), "Global");
-#else
-	KConfigGroup config(KGlobal::config(), "Global");
-#endif
 
 	// HACK: QTabWidget will bound its sizeHint to 200x200 unless scrollbuttons
 	// are disabled, so we disable them, get a decent sizehint and enable them
@@ -399,16 +364,16 @@ void KMixWindow::saveConfig()
 #endif
 
 	// TODO cesken The reason for not writing might be that we have multiple cascaded KConfig objects. I must migrate to KSharedConfig !!!
-	KGlobal::config()->sync();
-	kDebug()
+	KSharedConfig::openConfig()->sync();
+	qCDebug(KMIX_LOG)
 	<< "Saved config ... sync finished";
 }
 
 void KMixWindow::saveBaseConfig()
 {
-	GlobalConfig::instance().writeConfig();
+	GlobalConfig::instance().save();
 
-	KConfigGroup config(KGlobal::config(), "Global");
+	KConfigGroup config(KSharedConfig::openConfig(), "Global");
 
 	config.writeEntry("Size", size());
 	config.writeEntry("Position", pos());
@@ -430,7 +395,7 @@ void KMixWindow::saveBaseConfig()
 	QString mixerIgnoreExpression = MixerToolBox::instance()->mixerIgnoreExpression();
 	config.writeEntry("MixerIgnoreExpression", mixerIgnoreExpression);
 
-	kDebug()
+	qCDebug(KMIX_LOG)
 	<< "Base configuration saved";
 }
 
@@ -455,7 +420,7 @@ void KMixWindow::saveViewConfig()
 			KMixerWidget* mw = (KMixerWidget*) w;
 			// Here also Views are saved. even for Mixers that are closed. This is necessary when unplugging cards.
 			// Otherwise the user will be confused afer re-plugging the card (as the config was not saved).
-			mw->saveConfig(KGlobal::config().data());
+			mw->saveConfig(KSharedConfig::openConfig().data());
 			// add the view to the corresponding mixer list, so we can save a views-per-mixer list below
 //			if (!mw->mixer()->isDynamic())
 //			{
@@ -466,18 +431,18 @@ void KMixWindow::saveViewConfig()
 	}
 
 	// -2- Save Meta-Information (which views, and in which order). views-per-mixer list
-	KConfigGroup pconfig(KGlobal::config(), "Profiles");
+	KConfigGroup pconfig(KSharedConfig::openConfig(), "Profiles");
 	QMap<QString, QStringList>::const_iterator itEnd = mixerViews.constEnd();
 	for (QMap<QString, QStringList>::const_iterator it = mixerViews.constBegin(); it != itEnd; ++it)
 	{
 		const QString& mixerProfileKey = it.key(); // this is actually some mixer->id()
 		const QStringList& qslProfiles = it.value();
 		pconfig.writeEntry(mixerProfileKey, qslProfiles);
-		kDebug()
+		qCDebug(KMIX_LOG)
 		<< "Save Profile List for " << mixerProfileKey << ", number of views is " << qslProfiles.count();
 	}
 
-	kDebug()
+	qCDebug(KMIX_LOG)
 	<< "View configuration saved";
 }
 
@@ -504,7 +469,7 @@ void KMixWindow::saveVolumes(QString postfix)
 	}
 	cfg->sync();
 	delete cfg;
-	kDebug()
+	qCDebug(KMIX_LOG)
 	<< "Volume configuration saved";
 }
 
@@ -534,7 +499,7 @@ void KMixWindow::loadAndInitConfig(bool reset)
 
 void KMixWindow::loadBaseConfig()
 {
-	KConfigGroup config(KGlobal::config(), "Global");
+	KConfigGroup config(KSharedConfig::openConfig(), "Global");
 
 	GlobalConfigData& gcd = GlobalConfig::instance().data;
 
@@ -568,7 +533,7 @@ void KMixWindow::loadBaseConfig()
 
 	// The following log is very helpful in bug reports. Please keep it.
 	m_backendFilter = config.readEntry<>("Backends", QList<QString>());
-	kDebug()
+	qCDebug(KMIX_LOG)
 	<< "Backends: " << m_backendFilter;
 
 	// show/hide menu bar
@@ -592,7 +557,7 @@ void KMixWindow::loadVolumes()
 
 void KMixWindow::loadVolumes(QString postfix)
 {
-	kDebug()
+	qCDebug(KMIX_LOG)
 	<< "About to load config (Volume)";
 	const QString& kmixctrlRcFilename = getKmixctrlRcFilename(postfix);
 
@@ -649,7 +614,7 @@ void KMixWindow::recreateGUI(bool saveConfig, const QString& mixerId, bool force
 		Mixer *mixer = Mixer::findMixer( guiprof->getMixerId() );
 		if ( mixer == 0 )
 		{
-			kError() << "MixerToolBox::find() hasn't found the Mixer for the profile " << guiprof->getId();
+			qCCritical(KMIX_LOG) << "MixerToolBox::find() hasn't found the Mixer for the profile " << guiprof->getId();
 			continue;
 		}
 		mixerHasProfile[mixer] = true;
@@ -673,7 +638,7 @@ void KMixWindow::recreateGUI(bool saveConfig, const QString& mixerId, bool force
 
 
 	// -3- ADD TABS FOR Mixer instances that have no tab yet **********************************
-	KConfigGroup pconfig(KGlobal::config(), "Profiles");
+	KConfigGroup pconfig(KSharedConfig::openConfig(), "Profiles");
 	foreach ( Mixer *mixer, Mixer::mixers())
 	{
 		if ( mixerHasProfile.contains(mixer))
@@ -717,7 +682,7 @@ void KMixWindow::recreateGUI(bool saveConfig, const QString& mixerId, bool force
 			foreach ( QString profileId, profileList)
 			{
 				// This handles the profileList form the kmixrc
-				kDebug() << "Now searching for profile: " << profileId;
+				qCDebug(KMIX_LOG) << "Now searching for profile: " << profileId;
 				GUIProfile* guiprof = GUIProfile::find(mixer, profileId, true, false);// ### Card specific profile ###
 				if ( guiprof != 0 )
 				{
@@ -726,7 +691,7 @@ void KMixWindow::recreateGUI(bool saveConfig, const QString& mixerId, bool force
 				}
 				else
 				{
-					kError() << "Cannot load profile " << profileId << " . It was removed by the user, or the KMix config file is defective.";
+					qCCritical(KMIX_LOG) << "Cannot load profile " << profileId << " . It was removed by the user, or the KMix config file is defective.";
 				}
 			}
 
@@ -750,16 +715,16 @@ void KMixWindow::recreateGUI(bool saveConfig, const QString& mixerId, bool force
 			//     (Hint: This means the user cannot hide a device completely
 
 			// Lets try a bunch of fallback strategies:
-			kDebug() << "Attempting to find a card-specific GUI Profile for the mixer " << mixer->id();
+			qCDebug(KMIX_LOG) << "Attempting to find a card-specific GUI Profile for the mixer " << mixer->id();
 			GUIProfile* guiprof = GUIProfile::find(mixer, QString("default"), false, false);// ### Card specific profile ###
 			if ( guiprof == 0 )
 			{
-				kDebug() << "Not found. Attempting to find a generic GUI Profile for the mixer " << mixer->id();
+				qCDebug(KMIX_LOG) << "Not found. Attempting to find a generic GUI Profile for the mixer " << mixer->id();
 				guiprof = GUIProfile::find(mixer, QString("default"), false, true); // ### Card unspecific profile ###
 			}
 			if ( guiprof == 0)
 			{
-				kDebug() << "Using fallback GUI Profile for the mixer " << mixer->id();
+				qCDebug(KMIX_LOG) << "Using fallback GUI Profile for the mixer " << mixer->id();
 				// This means there is neither card specific nor card unspecific profile
 				// This is the case for some backends (as they don't ship profiles).
 				guiprof = GUIProfile::fallbackProfile(mixer);
@@ -772,7 +737,7 @@ void KMixWindow::recreateGUI(bool saveConfig, const QString& mixerId, bool force
 			}
 			else
 			{
-				kError() << "Cannot use ANY profile (including Fallback) for mixer " << mixer->id() << " . This is impossible, and thus this mixer can NOT be used.";
+				qCCritical(KMIX_LOG) << "Cannot use ANY profile (including Fallback) for mixer " << mixer->id() << " . This is impossible, and thus this mixer can NOT be used.";
 			}
 
 		}
@@ -819,7 +784,7 @@ void KMixWindow::newView()
 {
 	if (Mixer::mixers().empty())
 	{
-		kError() << "Trying to create a View, but no Mixer exists";
+		qCCritical(KMIX_LOG) << "Trying to create a View, but no Mixer exists";
 		return; // should never happen
 	}
 
@@ -832,33 +797,32 @@ void KMixWindow::newView()
 		QString profileName = dav->getresultViewName();
 		QString mixerId = dav->getresultMixerId();
 		mixer = Mixer::findMixer(mixerId);
-		kDebug()
+		qCDebug(KMIX_LOG)
 		<< ">>> mixer = " << mixerId << " -> " << mixer;
 
 		GUIProfile* guiprof = GUIProfile::find(mixer, profileName, false, false);
-		if (guiprof == 0)
+		if (guiprof == nullptr)
 		{
 			guiprof = GUIProfile::find(mixer, profileName, false, true);
 		}
 
-		if (guiprof == 0)
+		if (guiprof == nullptr)
 		{
-			static const QString msg(i18n("Cannot add view - GUIProfile is invalid."));
-			errorPopup(msg);
+			KMessageBox::sorry(this, i18n("Cannot add view - GUIProfile is invalid."), i18n("Error"));
 		}
 		else
 		{
 			bool ret = addMixerWidget(mixer->id(), guiprof->getId(), -1);
-			if (ret == false)
+			if (!ret)
 			{
-				errorPopup(i18n("View already exists. Cannot add View."));
+				KMessageBox::sorry(this, i18n("Cannot add view - View already exists."), i18n("Error"));
 			}
 		}
 
 		delete dav;
 	}
 
-	//kDebug() << "Exit";
+	//qCDebug(KMIX_LOG) << "Exit";
 }
 
 /**
@@ -868,41 +832,41 @@ void KMixWindow::newView()
  */
 void KMixWindow::saveAndCloseView(int idx)
 {
-	kDebug()
+	qCDebug(KMIX_LOG)
 	<< "Enter";
 	QWidget *w = m_wsMixers->widget(idx);
 	KMixerWidget* kmw = ::qobject_cast<KMixerWidget*>(w);
 	if (kmw)
 	{
-		kmw->saveConfig(KGlobal::config().data()); // -<- This alone is not enough, as I need to save the META information as well. Thus use saveViewConfig() below
+		kmw->saveConfig(KSharedConfig::openConfig().data()); // -<- This alone is not enough, as I need to save the META information as well. Thus use saveViewConfig() below
 		m_wsMixers->removeTab(idx);
 		updateTabsClosable();
 		saveViewConfig();
 		delete kmw;
 	}
-	kDebug()
+	qCDebug(KMIX_LOG)
 	<< "Exit";
 }
 
 void KMixWindow::fixConfigAfterRead()
 {
-	KConfigGroup grp(KGlobal::config(), "Global");
+	KConfigGroup grp(KSharedConfig::openConfig(), "Global");
 	unsigned int configVersion = grp.readEntry("ConfigVersion", 0);
 	if (configVersion < 3)
 	{
 		// Fix the "double Base" bug, by deleting all groups starting with "View.Base.Base.".
 		// The group has been copied over by KMixToolBox::loadView() for all soundcards, so
 		// we should be fine now
-		QStringList cfgGroups = KGlobal::config()->groupList();
+		QStringList cfgGroups = KSharedConfig::openConfig()->groupList();
 		QStringListIterator it(cfgGroups);
 		while (it.hasNext())
 		{
 			QString groupName = it.next();
 			if (groupName.indexOf("View.Base.Base") == 0)
 			{
-				kDebug(67100)
+				qCDebug(KMIX_LOG)
 				<< "Fixing group " << groupName;
-				KConfigGroup buggyDevgrpCG = KGlobal::config()->group(groupName);
+				KConfigGroup buggyDevgrpCG(KSharedConfig::openConfig(), groupName);
 				buggyDevgrpCG.deleteGroup();
 			} // remove buggy group
 		} // for all groups
@@ -911,7 +875,7 @@ void KMixWindow::fixConfigAfterRead()
 
 void KMixWindow::plugged(const char* driverName, const QString& udi, QString& dev)
 {
-	kDebug()
+	qCDebug(KMIX_LOG)
 	<< "Plugged: dev=" << dev << "(" << driverName << ") udi=" << udi << "\n";
 	QString driverNameString;
 	driverNameString = driverName;
@@ -919,7 +883,7 @@ void KMixWindow::plugged(const char* driverName, const QString& udi, QString& de
 	Mixer *mixer = new Mixer(driverNameString, devNum);
 	if (mixer != 0)
 	{
-		kDebug()
+		qCDebug(KMIX_LOG)
 		<< "Plugged: dev=" << dev << "\n";
 		if (MixerToolBox::instance()->possiblyAddMixer(mixer))
 			recreateGUI(true, mixer->id(), true, false);
@@ -928,15 +892,15 @@ void KMixWindow::plugged(const char* driverName, const QString& udi, QString& de
 
 void KMixWindow::unplugged(const QString& udi)
 {
-	kDebug()
+	qCDebug(KMIX_LOG)
 	<< "Unplugged: udi=" << udi << "\n";
 	for (int i = 0; i < Mixer::mixers().count(); ++i)
 	{
 		Mixer *mixer = (Mixer::mixers())[i];
-		//         kDebug(67100) << "Try Match with:" << mixer->udi() << "\n";
+		//         qCDebug(KMIX_LOG) << "Try Match with:" << mixer->udi() << "\n";
 		if (mixer->udi() == udi)
 		{
-			kDebug()
+			qCDebug(KMIX_LOG)
 			<< "Unplugged Match: Removing udi=" << udi << "\n";
 			//KMixToolBox::notification("MasterFallback", "aaa");
 			bool globalMasterMixerDestroyed = (mixer == Mixer::getGlobalMasterMixer());
@@ -1018,7 +982,7 @@ bool KMixWindow::profileExists(QString guiProfileId)
 
 bool KMixWindow::addMixerWidget(const QString& mixer_ID, QString guiprofId, int insertPosition)
 {
-	kDebug()
+	qCDebug(KMIX_LOG)
 	<< "Add " << guiprofId;
 	GUIProfile* guiprof = GUIProfile::find(guiprofId);
 	if (guiprof != 0 && profileExists(guiprof->getId())) // TODO Bad place. Should be checked in the add-tab-dialog
@@ -1027,7 +991,7 @@ bool KMixWindow::addMixerWidget(const QString& mixer_ID, QString guiprofId, int
 	if (mixer == 0)
 		return false; // no such Mixer
 
-	//       kDebug(67100) << "KMixWindow::addMixerWidget() " << mixer_ID << " is being added";
+	//       qCDebug(KMIX_LOG) << "KMixWindow::addMixerWidget() " << mixer_ID << " is being added";
 	ViewBase::ViewFlags vflags = ViewBase::HasMenuBar;
 	if ((_actionShowMenubar == 0) || _actionShowMenubar->isChecked())
 		vflags |= ViewBase::MenuBarVisible;
@@ -1065,7 +1029,7 @@ bool KMixWindow::addMixerWidget(const QString& mixer_ID, QString guiprofId, int
 	updateTabsClosable();
 	m_dontSetDefaultCardOnStart = false;
 
-	kmw->loadConfig(KGlobal::config().data());
+	kmw->loadConfig(KSharedConfig::openConfig().data());
 	// Now force to read for new tabs, especially after hotplug. Note: Doing it here is bad design and possibly
 	// obsolete, as the backend should take care of upating itself.
 	kmw->mixer()->readSetFromHWforceUpdate();
@@ -1082,7 +1046,7 @@ void KMixWindow::updateTabsClosable()
 bool KMixWindow::queryClose()
 {
 	GlobalConfigData& gcd = GlobalConfig::instance().data;
-	if (gcd.showDockWidget && !kapp->sessionSaving() )
+	if (gcd.showDockWidget && !qApp->isSavingSession() )
 	{
 		// Hide (don't close and destroy), if docking is enabled. Except when session saving (shutdown) is in process.
 		hide();
@@ -1093,7 +1057,7 @@ bool KMixWindow::queryClose()
 		// Accept the close, if:
 		//     The user has disabled docking
 		// or  SessionSaving() is running
-		//         kDebug(67100) << "close";
+		//         qCDebug(KMIX_LOG) << "close";
 		return true;
 	}
 }
@@ -1149,7 +1113,6 @@ void KMixWindow::showVolumeDisplay()
 	if (md.get() == 0)
 		return; // shouldn't happen, but lets play safe
 
-#ifdef X_KMIX_KF5_BUILD
     if (GlobalConfig::instance().data.showOSD) {
         QDBusMessage msg = QDBusMessage::createMethodCall(
             "org.kde.plasmashell",
@@ -1167,20 +1130,6 @@ void KMixWindow::showVolumeDisplay()
 
         QDBusConnection::sessionBus().asyncCall(msg);
     }
-#else
-    if (GlobalConfig::instance().data.showOSD) {
-        // Setting volume not required here anymore, as the OSD updates it by itself
-        osdWidget->show();
-        osdWidget->activateOSD(); //Enable the hide timer
-    }
-
-    //Center the OSD
-    QRect rect = KApplication::kApplication()->desktop()->screenGeometry(QCursor::pos());
-    QSize size = osdWidget->sizeHint();
-    int posX = rect.x() + (rect.width() - size.width()) / 2;
-    int posY = rect.y() + 4 * rect.height() / 5;
-    osdWidget->setGeometry(posX, posY, size.width(), size.height());
-#endif
 }
 
 /**
@@ -1201,8 +1150,8 @@ void KMixWindow::slotMute()
 
 void KMixWindow::quit()
 {
-	//     kDebug(67100) << "quit";
-	kapp->quit();
+	//     qCDebug(KMIX_LOG) << "quit";
+	qApp->quit();
 }
 
 /**
@@ -1241,10 +1190,10 @@ void KMixWindow::applyPrefs()
 
 	bool toplevelOrientationHasChanged = config.getToplevelOrientation() != configBefore.getToplevelOrientation();
 	bool traypopupOrientationHasChanged = config.getTraypopupOrientation() != configBefore.getTraypopupOrientation();
-	kDebug()
+	qCDebug(KMIX_LOG)
 	<< "toplevelOrientationHasChanged=" << toplevelOrientationHasChanged << ", config="
 			<< config.getToplevelOrientation() << ", configBefore=" << configBefore.getToplevelOrientation();
-	kDebug()
+	qCDebug(KMIX_LOG)
 	<< "trayOrientationHasChanged=" << traypopupOrientationHasChanged << ", config=" << config.getTraypopupOrientation()
 			<< ", configBefore=" << configBefore.getTraypopupOrientation();
 
@@ -1264,7 +1213,7 @@ void KMixWindow::applyPrefs()
 	// -3- Apply all changes ------------------------------------------------------------------
 
 //	this->repaint(); // make KMix look fast (saveConfig() often uses several seconds)
-	kapp->processEvents();
+	qApp->processEvents();
 
 	configDataSnapshot = GlobalConfig::instance().data; // create a new snapshot as all current changes are applied now
 
@@ -1285,14 +1234,7 @@ void KMixWindow::slotHWInfo()
 
 void KMixWindow::slotKdeAudioSetupExec()
 {
-	QStringList args;
-#ifdef X_KMIX_KF5_BUILD
-    args << "kcmshell5"
-#else
-    args << "kcmshell4"
-#endif
-         << "kcm_phonon";
-	forkExec(args);
+    forkExec(QStringList() << "kcmshell5" << "kcm_phonon");
 }
 
 void KMixWindow::forkExec(const QStringList& args)
@@ -1300,29 +1242,12 @@ void KMixWindow::forkExec(const QStringList& args)
 	int pid = KProcess::startDetached(args);
 	if (pid == 0)
 	{
-		static const QString startErrorMessage(i18n("The helper application is either not installed or not working."));
-		QString msg;
-		msg += startErrorMessage;
-		msg += "\n(";
-		msg += args.join(QLatin1String(" "));
-		msg += ')';
-		errorPopup(msg);
+		KMessageBox::error(this, i18n("The helper application is either not installed or not working.\n\n%1",
+					      args.join(QLatin1String(" "))));
 	}
 
 }
 
-void KMixWindow::errorPopup(const QString& msg)
-{
-	QPointer<KDialog> dialog = new KDialog(this);
-	dialog->setButtons(KDialog::Ok);
-	dialog->setCaption(i18n("Error"));
-	QLabel* qlbl = new QLabel(msg);
-	dialog->setMainWidget(qlbl);
-	dialog->exec();
-	delete dialog;
-	kWarning() << msg;
-}
-
 void KMixWindow::slotConfigureCurrentView()
 {
 	KMixerWidget* mw = (KMixerWidget*) m_wsMixers->currentWidget();
@@ -1366,8 +1291,10 @@ void KMixWindow::newMixerShown(int /*tabIndex*/)
 	{
 		// I am using the app name as a PREFIX, as KMix is a single window app, and it is
 		// more helpful to the user to see "KDE Mixer" in a window list than a possibly cryptic
-		// soundcard name like "HDA ATI SB"
-		setWindowTitle(i18n("KDE Mixer") + " - " + kmw->mixer()->readableName());
+		// soundcard name like "HDA ATI SB".
+		// Reformatted for KF5 so as to not say "KDE"
+		// and so that there are not two different dashes.
+		setWindowTitle(i18n("Mixer (%1)", kmw->mixer()->readableName()));
 		if (!m_dontSetDefaultCardOnStart)
 			m_defaultCardOnStart = kmw->getGuiprof()->getId();
 		// As switching the tab does NOT mean switching the master card, we do not need to update dock icon here.
